@@ -1,5 +1,5 @@
 package Reply::Plugin::Prompt;
-$Reply::Plugin::Prompt::VERSION = '0.0.18.0';
+$Reply::Plugin::Prompt::VERSION = '0.0.19.0';
 use strict;
 use warnings;
 use Cwd qw(abs_path getcwd);
@@ -48,7 +48,7 @@ sub new {
     return $self;
 }
 
-sub wakatime {
+sub section_wakatime {
     my $cmd = $wakatime_cmd;
     if ( $cmd =~ /%s/ ) {
         my $null    = $^O eq 'MSWin32' ? 'nul' : '/dev/null';
@@ -58,13 +58,7 @@ sub wakatime {
         $project = basename $project;
         $cmd     = sprintf( $cmd, $project );
     }
-    system($cmd);
-}
-
-sub section_wakatime {
-    require threads;
-    my $thr = threads->new( \&wakatime );
-    $thr->detach();
+    open my $fh, '-|', $cmd;
 }
 
 sub section_result {
@@ -194,11 +188,18 @@ sub prompt {
             die "$section is not supported!";
         }
         my $color = $section_colors{$section};
-        if ( $last_bg ne '' ) {
+        if ( $last_bg eq '' ) {
+            $ps1 .= color($color) . sprintf( $insert_text, $text );
+        }
+        else {
             my ($bg) = $color =~ /(?<=on_)(\S+)/g;
-            $ps1 .= color("$last_bg on_$bg") . $sep;
+            my ($fg) = $color =~ /(?<!on_)(\S+)/g;
+            $ps1 .=
+                color("$last_bg on_$bg")
+              . $sep
+              . color($fg)
+              . sprintf( $insert_text, $text );
         }
-        $ps1 .= color($color) . sprintf( $insert_text, $text );
         ($last_bg) = $color =~ /(?<=on_)(\S+)/g;
     }
     return
@@ -229,7 +230,7 @@ Reply::Plugin::Prompt - reply plugin for powerlevel10k style prompt
 
 =head1 VERSION
 
-version 0.0.18.0
+version 0.0.19.0
 
 =head1 DESCRIPTION
 
@@ -238,7 +239,7 @@ style prompt. It is an enhancement of L<Reply::Plugin::FancyPrompt>.
 
 Your perl deserves a beautiful REPL.
 
-See L<README.md|https://github.com/Freed-Wu/Reply-Plugin-Prompt> for screenshots.
+See L<README.md|https://github.com/wakatime/Reply-Plugin-Prompt> for screenshots.
 
 Now this plugin supports L<wakatime|https://wakatime.com> which will record your
 time to use perl in L<Reply>. If you don't want it, please remove I<wakatime>
